@@ -156,7 +156,7 @@ build_figures <- function(obnd        = NULL,
 
       # Checking the covariates to make sure they are in the dataset
       if(!is.null(cat_covars)){
-        missing_covars = cat_covars[!(cat_covars %in% names(fit[["origData"]]))]
+        missing_covars = cat_covars[!(cat_covars %in% names(fit$origData))]
         if(length(missing_covars) > 0){
           if(verbose){
             cli::cli_alert_warning(paste0("The following categorical covariates were specified"))
@@ -166,7 +166,7 @@ build_figures <- function(obnd        = NULL,
         }
 
         # Removing the missing covariates
-        cat_covars = cat_covars[cat_covars[cat_covars %in% names(fit$origData)]]
+        cat_covars = cat_covars[cat_covars %in% names(fit$origData)]
         if(length(cat_covars) == 0){
           cat_covars = NULL}
       }
@@ -187,7 +187,7 @@ build_figures <- function(obnd        = NULL,
         }
 
         # Removing the missing covariates
-        cont_covars = cont_covars[cont_covars[cont_covars %in% names(fit[["origData"]])]]
+        cont_covars = cont_covars[cont_covars %in% names(fit$origData)]
         if(length(cont_covars) == 0){
           cont_covars = NULL}
       }
@@ -246,7 +246,7 @@ build_figures <- function(obnd        = NULL,
                # Some errors don't show up until the figures are built
                # while saving. This will force ggplot objects to be built
                # and trap any errors to be passed on to the user.
-               if(is.ggplot(p_res)){
+               if(is_ggplot(p_res)){
                  ggplot2::ggplot_build(p_res)
                }
               list(isgood=TRUE, p_res=p_res)},
@@ -274,7 +274,7 @@ build_figures <- function(obnd        = NULL,
             if(verbose){
               cli::cli_h3("Figure generation failed")
               for(msg in fmsgs){
-                cli::cli_alert(msg)
+                cli::cli_alert(safe_text(msg))
               }
             }
 
@@ -287,9 +287,25 @@ build_figures <- function(obnd        = NULL,
         }
 
         figure = c()
-        # Figuring out if we have a ggplot or an image file:
+        # Figuring out if we have a ggplot, an image file, ggmatrix or skipping the figure:
+        # A p_type of NULL means we couldnt' figure it out
+        p_type = NULL
+        if(is.na(p_res)){
+          p_type = "skip"
+        }
+        if(ggplot2::is_ggplot(p_res)){
+          p_type = "ggplot"
+        }
+        if(is.null(p_type) & system.file(package="GGally") != ""){
+          if(GGally::is_ggmatrix(p_res)){
+            p_type = "ggmatrix"
+          }
+        }
+        if(is.null(p_type) & is.character(p_res)){
+          p_type = "file_path"
+        }
 
-        if(is.ggplot(p_res)){
+        if(p_type == "ggplot"){
           # This is the number of figure pages in the current figure. If
           # The figure isn't paginated, it will return NULL
           nfpages = ggforce::n_pages(p_res)
@@ -339,15 +355,33 @@ build_figures <- function(obnd        = NULL,
           }
           # Closing the subbullets
           if(verbose){cli::cli_end(cli_list_fn)}
-        } else if(is.na(p_res)){
+        } else if(p_type == "ggmatrix"){
+          fig_file = file.path(output_dir, paste0(fid, "-", rpttype, ".png"))
+          if(verbose){ cli::cli_li(fig_file) }
+          figure   = c(fig_file)
+          wfres = write_figure(
+            p_res              = p_res,
+            page               = NULL,
+            width              = width,
+            height             = height,
+            resolution         = resolution,
+            fig_file           = fig_file,
+            fig_stamp          = fig_stamp,
+            verbose            = verbose)
+        } else if(p_type == "skip"){
           # Figure was set to NA to skip
           SKIP   = TRUE
           figure = p_res
-        } else if(is.character(p_res)){
+        } else if(p_type == "file_path"){
           #JMH test this with a vector of image files
           if(file.exists(p_res)){
             figure = p_res
           }
+        } else if(is.null(p_type)){
+          msgs = c(msgs, paste0("unable to determine the file type of ", fid, " will not be included in the report"))
+          if(verbose){
+            cli::cli_alert_warning( paste0("unable to determine the file type of ", fid, " will not be included in report"))
+          }
         }
 
         # Storing the caption format for alter use
@@ -522,13 +556,12 @@ write_figure  <- function(p_res              = NULL,
     tryCatch(
       {
        # Adding stamps if necessary
-       if(is.ggplot(p_res)){
+       if(is_ggplot(p_res)){
          if(!is.null(fig_stamp)){
            # If we are processing a ggplot object and fig_stamp has been
            # defined we append the fig_stamp to the figure:
            fig_stamp = stringr::str_replace_all(fig_stamp, "===FILE===", fig_file)
 
-
           ## If the plot is a ggplot but hasn't been arranged we arrange it
           ## so we can stamp it
           #if(!("ggarrange" %in% class(p_res)) & ("ggplot" %in% class(p_res))){
@@ -600,11 +633,11 @@ write_figure  <- function(p_res              = NULL,
     if(verbose){
       cli::cli_h3("Writing figure failed:")
       for(msg in msgs){
-        cli::cli_alert(msg)
+        cli::cli_alert(safe_text(msg))
       }
     }
   }
 
   res = list(isgood = isgood,
              msgs   = msgs)
-res}
+  res}
